@@ -74,8 +74,6 @@ class TaskAssignator:
         dt_status = self.dt_status
         dt_group = self.dt_group
         msg_in = []
-        rprint("Assignator")
-        rprint(args)
         try:
             tasks = []
             W = 0
