@@ -132,6 +132,13 @@ class TaskScheduler:
         result_args, result_kwargs = [], {}
         log = kwargs.get('log')
         try:
+            gprint("="*20)
+            rprint("Task...")
+            bprint("IPT_>%s ICO_> %s" %(ipt, ico))
+            rprint("args")
+            bprint(args)
+            gprint("="*20)
+
             if assigned_task:
                 if not self.sta_init.get(assigned_task):
                     args, kwargs = self.set_pst(assigned_task, args, kwargs)
